@@ -9,7 +9,11 @@ DEFAULT_POOL = "processes"
 if is_jython:
     DEFAULT_POOL = "threads"
 elif is_pypy:
-    DEFAULT_POOL = "solo"
+    if sys.pypy_version_info[0:3] < (1, 5, 0):
+        DEFAULT_POOL = "solo"
+    else:
+        DEFAULT_POOL = "processes"
+
 
 DEFAULT_PROCESS_LOG_FMT = """
     [%(asctime)s: %(levelname)s/%(processName)s] %(message)s
@@ -41,18 +45,19 @@ class Option(object):
 
 NAMESPACES = {
     "BROKER": {
-        "HOST": Option("localhost"),
+        "HOST": Option(None, type="string"),
         "PORT": Option(type="int"),
-        "USER": Option("guest"),
-        "PASSWORD": Option("guest"),
-        "VHOST": Option("/"),
-        "BACKEND": Option(),
+        "USER": Option(None, type="string"),
+        "PASSWORD": Option(None, type="string"),
+        "VHOST": Option(None, type="string"),
         "CONNECTION_TIMEOUT": Option(4, type="int"),
         "CONNECTION_RETRY": Option(True, type="bool"),
         "CONNECTION_MAX_RETRIES": Option(100, type="int"),
+        "POOL_LIMIT": Option(None, type="int"),
         "INSIST": Option(False, type="bool"),
         "USE_SSL": Option(False, type="bool"),
-        "TRANSPORT_OPTIONS": Option({}, type="dict")
+        "TRANSPORT": Option(None, type="string"),
+        "TRANSPORT_OPTIONS": Option({}, type="dict"),
     },
     "CELERY": {
         "ACKS_LATE": Option(False, type="bool"),
@@ -78,7 +83,12 @@ NAMESPACES = {
         "IGNORE_RESULT": Option(False, type="bool"),
         "MAX_CACHED_RESULTS": Option(5000, type="int"),
         "MESSAGE_COMPRESSION": Option(None, type="string"),
-        "RESULT_BACKEND": Option("amqp"),
+        "MONGODB_BACKEND_SETTINGS": Option(None, type="dict"),
+        "REDIS_HOST": Option(None, type="string"),
+        "REDIS_PORT": Option(None, type="int"),
+        "REDIS_DB": Option(None, type="int"),
+        "REDIS_PASSWORD": Option(None, type="string"),
+        "RESULT_BACKEND": Option(None, type="string"),
         "RESULT_DBURI": Option(),
         "RESULT_ENGINE_OPTIONS": Option(None, type="dict"),
         "RESULT_EXCHANGE": Option("celeryresults"),
@@ -91,11 +101,11 @@ NAMESPACES = {
         "SEND_TASK_SENT_EVENT": Option(False, type="bool"),
         "STORE_ERRORS_EVEN_IF_IGNORED": Option(False, type="bool"),
         "TASK_ERROR_WHITELIST": Option((), type="tuple"),
-        "TASK_PUBLISH_RETRY": Option(False, type="bool"),
+        "TASK_PUBLISH_RETRY": Option(True, type="bool"),
         "TASK_PUBLISH_RETRY_POLICY": Option({
-                "max_retries": 3,
+                "max_retries": 100,
                 "interval_start": 0,
-                "interval_max": 0.2,
+                "interval_max": 1,
                 "interval_step": 0.2}, type="dict"),
         "TASK_RESULT_EXPIRES": Option(timedelta(days=1), type="int"),
         "TASK_SERIALIZER": Option("pickle"),
@@ -144,9 +154,14 @@ NAMESPACES = {
         "HOST_USER": Option(None),
         "HOST_PASSWORD": Option(None),
         "TIMEOUT": Option(2, type="int"),
+        "USE_SSL": Option(False, type="bool"),
     },
     "SERVER_EMAIL": Option("celery@localhost"),
     "ADMINS": Option((), type="tuple"),
+    "TT": {
+        "HOST": Option(None, type="string"),
+        "PORT": Option(None, type="int"),
+    },
 }
 
 
