@@ -1,9 +1,12 @@
+from __future__ import with_statement
+
 import socket
 import sys
 
 from datetime import timedelta
 from Queue import Empty, Queue
 
+from celery import current_app
 from celery import states
 from celery.app import app_or_default
 from celery.backends.amqp import AMQPBackend
@@ -111,7 +114,6 @@ class test_AMQPBackend(unittest.TestCase):
         self.assertRaises(KeyError, backend.store_result,
                           "foo", "bar", "STARTED", max_retries=None)
 
-        print(backend.store_result)
         self.assertRaises(KeyError, backend.store_result,
                           "foo", "bar", "STARTED", max_retries=10)
 
@@ -202,16 +204,11 @@ class test_AMQPBackend(unittest.TestCase):
                 pass
 
         b = self.create_backend()
-        conn = b.pool.acquire(block=False)
-        channel = conn.channel()
-        try:
+        with current_app.pool.acquire_channel(block=False) as (_, channel):
             binding = b._create_binding(gen_unique_id())
             consumer = b._create_consumer(binding, channel)
             self.assertRaises(socket.timeout, b.drain_events,
                               Connection(), consumer, timeout=0.1)
-        finally:
-            channel.close()
-            conn.release()
 
     def test_get_many(self):
         b = self.create_backend()
@@ -228,10 +225,10 @@ class test_AMQPBackend(unittest.TestCase):
                                     "traceback": None,
                                     "task_id": uuid})
                                 for i, uuid in enumerate(uuids)]
-        self.assertItemsEqual(res, expected_results)
+        self.assertEqual(sorted(res), sorted(expected_results))
         self.assertDictEqual(b._cache[res[0][0]], res[0][1])
         cached_res = list(b.get_many(uuids, timeout=1))
-        self.assertItemsEqual(cached_res, expected_results)
+        self.assertEqual(sorted(cached_res), sorted(expected_results))
         b._cache[res[0][0]]["status"] = states.RETRY
         self.assertRaises(socket.timeout, list,
                           b.get_many(uuids, timeout=0.01))
@@ -286,3 +283,7 @@ class test_AMQPBackend(unittest.TestCase):
     def test_restore_taskset(self):
         self.assertRaises(NotImplementedError,
                           self.create_backend().restore_taskset, "x")
+
+    def test_delete_taskset(self):
+        self.assertRaises(NotImplementedError,
+                          self.create_backend().delete_taskset, "x")
