@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from __future__ import with_statement
+
 import anyjson
 import logging
 import os
@@ -20,14 +22,14 @@ from celery.log import setup_logger
 from celery.result import AsyncResult
 from celery.task.base import Task
 from celery.utils import gen_unique_id
-from celery.worker.job import WorkerTaskTrace, TaskRequest
-from celery.worker.job import execute_and_trace, AlreadyExecutedError
-from celery.worker.job import InvalidTaskError
+from celery.worker.job import (WorkerTaskTrace, TaskRequest,
+                               InvalidTaskError, execute_and_trace,
+                               default_encode)
 from celery.worker.state import revoked
 
 from celery.tests.compat import catch_warnings
 from celery.tests.utils import unittest
-from celery.tests.utils import execute_context, StringIO, wrap_logger
+from celery.tests.utils import StringIO, wrap_logger
 
 
 scratch = {"ACK": False}
@@ -70,6 +72,26 @@ def mytask_raising(i, **kwargs):
     raise KeyError(i)
 
 
+class test_default_encode(unittest.TestCase):
+
+    def test_jython(self):
+        prev, sys.platform = sys.platform, "java 1.6.1"
+        try:
+            self.assertEqual(default_encode("foo"), "foo")
+        finally:
+            sys.platform = prev
+
+    def test_cython(self):
+        prev, sys.platform = sys.platform, "darwin"
+        gfe, sys.getfilesystemencoding = sys.getfilesystemencoding, \
+                                         lambda: "utf-8"
+        try:
+            self.assertEqual(default_encode("foo"), "foo")
+        finally:
+            sys.platform = prev
+            sys.getfilesystemencoding = gfe
+
+
 class test_RetryTaskError(unittest.TestCase):
 
     def test_retry_task_error(self):
@@ -89,19 +111,14 @@ class test_WorkerTaskTrace(unittest.TestCase):
         mytask.backend.process_cleanup = Mock(side_effect=KeyError())
         try:
 
-            def with_wrap_logger(sio):
+            logger = mytask.app.log.get_default_logger()
+            with wrap_logger(logger) as sio:
                 uuid = gen_unique_id()
                 ret = jail(uuid, mytask.name, [2], {})
                 self.assertEqual(ret, 4)
                 mytask.backend.mark_as_done.assert_called_with(uuid, 4)
                 logs = sio.getvalue().strip()
                 self.assertIn("Process cleanup failed", logs)
-                return 1234
-
-            logger = mytask.app.log.get_default_logger()
-            self.assertEqual(execute_context(
-                    wrap_logger(logger), with_wrap_logger), 1234)
-
         finally:
             mytask.backend = backend
 
@@ -201,6 +218,23 @@ class test_TaskRequest(unittest.TestCase):
         tw.on_failure(einfo)
         self.assertIn("task-retried", tw.eventer.sent)
 
+    def test_terminate__task_started(self):
+        pool = Mock()
+        tw = TaskRequest(mytask.name, gen_unique_id(), [1], {"f": "x"})
+        tw.time_start = time.time()
+        tw.worker_pid = 313
+        tw.terminate(pool, signal="KILL")
+        pool.terminate_job.assert_called_with(tw.worker_pid, "KILL")
+
+    def test_terminate__task_reserved(self):
+        pool = Mock()
+        tw = TaskRequest(mytask.name, gen_unique_id(), [1], {"f": "x"})
+        tw.time_start = None
+        tw.terminate(pool, signal="KILL")
+        self.assertFalse(pool.terminate_job.call_count)
+        self.assertTupleEqual(tw._terminate_on_ack, (True, pool, "KILL"))
+        tw.terminate(pool, signal="KILL")
+
     def test_revoked_expires_expired(self):
         tw = TaskRequest(mytask.name, gen_unique_id(), [1], {"f": "x"})
         tw.expires = datetime.now() - timedelta(days=1)
@@ -318,6 +352,14 @@ class test_TaskRequest(unittest.TestCase):
         finally:
             mytask.acks_late = False
 
+    def test_on_accepted_terminates(self):
+        tw = TaskRequest(mytask.name, gen_unique_id(), [1], {"f": "x"})
+        pool = Mock()
+        tw.terminate(pool, signal="KILL")
+        self.assertFalse(pool.terminate_job.call_count)
+        tw.on_accepted(pid=314, time_accepted=time.time())
+        pool.terminate_job.assert_called_with(314, "KILL")
+
     def test_on_success_acks_early(self):
         tw = TaskRequest(mytask.name, gen_unique_id(), [1], {"f": "x"})
         tw.time_start = 1
@@ -388,10 +430,11 @@ class test_TaskRequest(unittest.TestCase):
 
         tw = TaskRequest(mytask.name, gen_unique_id(), [1], {"f": "x"})
         tw.logger = MockLogger()
-        tw.on_timeout(soft=True)
-        self.assertIn("Soft time limit exceeded", tw.logger.warnings[0])
-        tw.on_timeout(soft=False)
-        self.assertIn("Hard time limit exceeded", tw.logger.errors[0])
+        tw.on_timeout(soft=True, timeout=1337)
+        self.assertIn("Soft time limit (1337s) exceeded",
+                      tw.logger.warnings[0])
+        tw.on_timeout(soft=False, timeout=1337)
+        self.assertIn("Hard time limit (1337s) exceeded", tw.logger.errors[0])
         self.assertEqual(mytask.backend.get_status(tw.task_id),
                          states.FAILURE)
 
@@ -401,7 +444,7 @@ class test_TaskRequest(unittest.TestCase):
             tw.logger = MockLogger()
         finally:
             mytask.ignore_result = False
-            tw.on_timeout(soft=True)
+            tw.on_timeout(soft=True, timeout=1336)
             self.assertEqual(mytask.backend.get_status(tw.task_id),
                              states.PENDING)
 
@@ -417,16 +460,13 @@ class test_TaskRequest(unittest.TestCase):
 
         WorkerTaskTrace.execute = _error_exec
         try:
-            def with_catch_warnings(log):
+            with catch_warnings(record=True) as log:
                 res = execute_and_trace(mytask.name, gen_unique_id(),
                                         [4], {})
                 self.assertIsInstance(res, ExceptionInfo)
                 self.assertTrue(log)
                 self.assertIn("Exception outside", log[0].message.args[0])
                 self.assertIn("KeyError", log[0].message.args[0])
-
-            context = catch_warnings(record=True)
-            execute_context(context, with_catch_warnings)
         finally:
             WorkerTaskTrace.execute = old_exec
 
@@ -461,13 +501,6 @@ class test_TaskRequest(unittest.TestCase):
         w.handle_failure(value_, type_, tb_, "")
         self.assertEqual(mytask.backend.get_status(uuid), states.FAILURE)
 
-    def test_executed_bit(self):
-        tw = TaskRequest(mytask.name, gen_unique_id(), [], {})
-        self.assertFalse(tw.executed)
-        tw._set_executed_bit()
-        self.assertTrue(tw.executed)
-        self.assertRaises(AlreadyExecutedError, tw._set_executed_bit)
-
     def test_task_wrapper_mail_attrs(self):
         tw = TaskRequest(mytask.name, gen_unique_id(), [], {})
         x = tw.success_msg % {"name": tw.task_name,
