@@ -1,23 +1,25 @@
-from __future__ import generators
+from __future__ import absolute_import
+from __future__ import with_statement
 
 import os
 import sys
 import operator
+import imp as _imp
 import importlib
 import logging
 import threading
 import traceback
 import warnings
 
+from contextlib import contextmanager
+from functools import partial, wraps
 from inspect import getargspec
 from itertools import islice
 from pprint import pprint
 
-from kombu.utils import gen_unique_id, rpartition, cached_property
+from kombu.utils import cached_property, gen_unique_id  # noqa
 
 from celery.utils.compat import StringIO
-from celery.utils.functional import partial, wraps
-
 
 LOG_LEVELS = dict(logging._levelNames)
 LOG_LEVELS["FATAL"] = logging.FATAL
@@ -306,7 +308,7 @@ def get_cls_by_name(name, aliases={}, imp=None):
         return name                                 # already a class
 
     name = aliases.get(name) or name
-    module_name, _, cls_name = rpartition(name, ".")
+    module_name, _, cls_name = name.rpartition(".")
     try:
         module = imp(module_name)
     except ValueError, exc:
@@ -344,7 +346,7 @@ def abbrtask(S, max):
     if S is None:
         return "???"
     if len(S) > max:
-        module, _, cls = rpartition(S, ".")
+        module, _, cls = S.rpartition(".")
         module = abbr(module, max - len(cls) - 3, False)
         return module + "[.]" + cls
     return S
@@ -361,6 +363,37 @@ def textindent(t, indent=0):
         return "\n".join(" " * indent + p for p in t.split("\n"))
 
 
+@contextmanager
+def cwd_in_path():
+    cwd = os.getcwd()
+    if cwd in sys.path:
+        yield
+    else:
+        sys.path.insert(0, cwd)
+        try:
+            yield cwd
+        finally:
+            try:
+                sys.path.remove(cwd)
+            except ValueError:
+                pass
+
+
+def find_module(module, path=None, imp=None):
+    """Version of :func:`imp.find_module` supporting dots."""
+    if imp is None:
+        imp = importlib.import_module
+    with cwd_in_path():
+        if "." in module:
+            last = None
+            parts = module.split(".")
+            for i, part in enumerate(parts[:-1]):
+                path = imp(".".join(parts[:i + 1])).__path__
+                last = _imp.find_module(parts[i + 1], path)
+            return last
+        return _imp.find_module(module)
+
+
 def import_from_cwd(module, imp=None):
     """Import module, but make sure it finds modules
     located in the current directory.
@@ -370,20 +403,11 @@ def import_from_cwd(module, imp=None):
     """
     if imp is None:
         imp = importlib.import_module
-    cwd = os.getcwd()
-    if cwd in sys.path:
+    with cwd_in_path():
         return imp(module)
-    sys.path.insert(0, cwd)
-    try:
-        return imp(module)
-    finally:
-        try:
-            sys.path.remove(cwd)
-        except ValueError:
-            pass
 
 
-def cry():
+def cry():  # pragma: no cover
     """Return stacktrace of all active threads.
 
     From https://gist.github.com/737056
@@ -400,14 +424,22 @@ def cry():
             main_thread = t
 
     out = StringIO()
+    sep = "=" * 49 + "\n"
     for tid, frame in sys._current_frames().iteritems():
         thread = tmap.get(tid, main_thread)
         out.write("%s\n" % (thread.getName(), ))
-        out.write("=================================================\n")
+        out.write(sep)
         traceback.print_stack(frame, file=out)
-        out.write("=================================================\n")
+        out.write(sep)
         out.write("LOCAL VARIABLES\n")
-        out.write("=================================================\n")
+        out.write(sep)
         pprint(frame.f_locals, stream=out)
         out.write("\n\n")
     return out.getvalue()
+
+
+def reprcall(name, args=(), kwargs=(), sep=', ',
+        kwformat=lambda i: "%s=%r" % i):
+    return "%s(%s%s%s)" % (name, sep.join(map(repr, args)),
+                           kwargs and sep or "",
+                           sep.join(map(kwformat, kwargs.iteritems())))
