@@ -1,6 +1,6 @@
 """timer2 - Scheduler for Python functions."""
-
-from __future__ import generators
+from __future__ import absolute_import
+from __future__ import with_statement
 
 import atexit
 import heapq
@@ -78,16 +78,15 @@ class Schedule(object):
         :keyword priority: Unused.
 
         """
+        if eta is None:  # schedule now
+            eta = datetime.now()
+
         try:
             eta = to_timestamp(eta)
         except OverflowError:
             if not self.handle_error(sys.exc_info()):
                 raise
 
-        if eta is None:
-            # schedule now.
-            eta = time()
-
         heapq.heappush(self._queue, (eta, priority, entry))
         return entry
 
@@ -167,16 +166,14 @@ class Timer(Thread):
                 traceback.print_exception(typ, val, tb)
 
     def next(self):
-        self.not_empty.acquire()
-        try:
+        with self.not_empty:
             delay, entry = self.scheduler.next()
             if entry is None:
                 if delay is None:
                     self.not_empty.wait(1.0)
                 return delay
-        finally:
-            self.not_empty.release()
         return self.apply_entry(entry)
+    __next__ = next  # for 2to3
 
     def run(self):
         try:
@@ -188,12 +185,12 @@ class Timer(Thread):
                 if delay:
                     if self.on_tick:
                         self.on_tick(delay)
-                    if sleep is None:
+                    if sleep is None:  # pragma: no cover
                         break
                     sleep(delay)
             try:
                 self._stopped.set()
-            except TypeError:           # pragma: no cover
+            except TypeError:  # pragma: no cover
                 # we lost the race at interpreter shutdown,
                 # so gc collected built-in modules.
                 pass
@@ -215,13 +212,10 @@ class Timer(Thread):
 
     def enter(self, entry, eta, priority=None):
         self.ensure_started()
-        self.mutex.acquire()
-        try:
+        with self.mutex:
             entry = self.schedule.enter(entry, eta, priority)
             self.not_empty.notify()
             return entry
-        finally:
-            self.mutex.release()
 
     def apply_at(self, eta, fun, args=(), kwargs={}, priority=0):
         return self.enter(self.Entry(fun, args, kwargs), eta, priority)
@@ -262,7 +256,7 @@ class Timer(Thread):
     def queue(self):
         return self.schedule.queue
 
-_default_timer = Timer()
+default_timer = _default_timer = Timer()
 apply_after = _default_timer.apply_after
 apply_at = _default_timer.apply_at
 apply_interval = _default_timer.apply_interval
