@@ -1,3 +1,6 @@
+from __future__ import absolute_import
+from __future__ import with_statement
+
 import threading
 
 from collections import deque
@@ -6,7 +9,7 @@ from Queue import Queue, Empty
 
 from celery.datastructures import TokenBucket
 from celery.utils import timeutils
-from celery.utils.compat import all, izip_longest, chain_from_iterable
+from celery.utils.compat import izip_longest, chain_from_iterable
 
 
 class RateLimitExceeded(Exception):
@@ -51,14 +54,11 @@ class TaskBucket(object):
     def put(self, request):
         """Put a :class:`~celery.worker.job.TaskRequest` into
         the appropiate bucket."""
-        self.mutex.acquire()
-        try:
+        with self.mutex:
             if request.task_name not in self.buckets:
                 self.add_bucket_for_type(request.task_name)
             self.buckets[request.task_name].put_nowait(request)
             self.not_empty.notify()
-        finally:
-            self.mutex.release()
     put_nowait = put
 
     def _get_immediate(self):
@@ -113,8 +113,7 @@ class TaskBucket(object):
         time_start = time()
         did_timeout = lambda: timeout and time() - time_start > timeout
 
-        self.not_empty.acquire()
-        try:
+        with self.not_empty:
             while True:
                 try:
                     remaining_time, item = self._get()
@@ -129,8 +128,6 @@ class TaskBucket(object):
                     sleep(min(remaining_time, timeout or 1))
                 else:
                     return item
-        finally:
-            self.not_empty.release()
 
     def get_nowait(self):
         return self.get(block=False)
@@ -301,10 +298,12 @@ class TokenBucketQueue(object):
     def wait(self, block=False):
         """Wait until a token can be retrieved from the bucket and return
         the next item."""
-        while True:
-            remaining = self.expected_time()
+        get = self.get
+        expected_time = self.expected_time
+        while 1:
+            remaining = expected_time()
             if not remaining:
-                return self.get(block=block)
+                return get(block=block)
             sleep(remaining)
 
     def expected_time(self, tokens=1):
